==> zio-aws-s3_3-5.17.158.4-sources.jar: zio/aws/s3/model/PutBucketReplicationRequest.scala <==
package zio.aws.s3.model
import zio.aws.s3.model.primitives.{
  AccountId,
  ObjectLockToken,
  ContentMD5,
  BucketName
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class PutBucketReplicationRequest(
    bucket: BucketName,
    contentMD5: Option[ContentMD5] = None,
    checksumAlgorithm: Option[zio.aws.s3.model.ChecksumAlgorithm] = None,
    replicationConfiguration: zio.aws.s3.model.ReplicationConfiguration,
    token: Option[ObjectLockToken] = None,
    expectedBucketOwner: Option[AccountId] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.PutBucketReplicationRequest = {
    import PutBucketReplicationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.PutBucketReplicationRequest
      .builder()
      .bucket(BucketName.unwrap(bucket): java.lang.String)
      .optionallyWith(
        contentMD5.map(value => ContentMD5.unwrap(value): java.lang.String)
      )(_.contentMD5)
      .optionallyWith(checksumAlgorithm.map(value => value.unwrap))(
        _.checksumAlgorithm
      )
      .replicationConfiguration(replicationConfiguration.buildAwsValue())
      .optionallyWith(
        token.map(value => ObjectLockToken.unwrap(value): java.lang.String)
      )(_.token)
      .optionallyWith(
        expectedBucketOwner.map(value =>
          AccountId.unwrap(value): java.lang.String
        )
      )(_.expectedBucketOwner)
      .build()
  }
  def asReadOnly: zio.aws.s3.model.PutBucketReplicationRequest.ReadOnly =
    zio.aws.s3.model.PutBucketReplicationRequest.wrap(buildAwsValue())
}
object PutBucketReplicationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.PutBucketReplicationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.PutBucketReplicationRequest =
      zio.aws.s3.model.PutBucketReplicationRequest(
        bucket,
        contentMD5.map(value => value),
        checksumAlgorithm.map(value => value),
        replicationConfiguration.asEditable,
        token.map(value => value),
        expectedBucketOwner.map(value => value)
      )
    def bucket: BucketName
    def contentMD5: Option[ContentMD5]
    def checksumAlgorithm: Option[zio.aws.s3.model.ChecksumAlgorithm]
    def replicationConfiguration
        : zio.aws.s3.model.ReplicationConfiguration.ReadOnly
    def token: Option[ObjectLockToken]
    def expectedBucketOwner: Option[AccountId]
    def getBucket: ZIO[Any, Nothing, BucketName] = ZIO.succeed(bucket)
    def getContentMD5: ZIO[Any, AwsError, ContentMD5] =
      AwsError.unwrapOptionField("contentMD5", contentMD5)
    def getChecksumAlgorithm
        : ZIO[Any, AwsError, zio.aws.s3.model.ChecksumAlgorithm] =
      AwsError.unwrapOptionField("checksumAlgorithm", checksumAlgorithm)
    def getReplicationConfiguration: ZIO[
      Any,
      Nothing,
      zio.aws.s3.model.ReplicationConfiguration.ReadOnly
    ] = ZIO.succeed(replicationConfiguration)
    def getToken: ZIO[Any, AwsError, ObjectLockToken] =
      AwsError.unwrapOptionField("token", token)
    def getExpectedBucketOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("expectedBucketOwner", expectedBucketOwner)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.PutBucketReplicationRequest
  ) extends zio.aws.s3.model.PutBucketReplicationRequest.ReadOnly {
    override val bucket: BucketName =
      zio.aws.s3.model.primitives.BucketName(impl.bucket())
    override val contentMD5: Option[ContentMD5] = scala
      .Option(impl.contentMD5())
      .map(value => zio.aws.s3.model.primitives.ContentMD5(value))
    override val checksumAlgorithm: Option[zio.aws.s3.model.ChecksumAlgorithm] =
      scala
        .Option(impl.checksumAlgorithm())
        .map(value => zio.aws.s3.model.ChecksumAlgorithm.wrap(value))
    override val replicationConfiguration
        : zio.aws.s3.model.ReplicationConfiguration.ReadOnly =
      zio.aws.s3.model.ReplicationConfiguration
        .wrap(impl.replicationConfiguration())
    override val token: Option[ObjectLockToken] = scala
      .Option(impl.token())
      .map(value => zio.aws.s3.model.primitives.ObjectLockToken(value))
    override val expectedBucketOwner: Option[AccountId] = scala
      .Option(impl.expectedBucketOwner())
      .map(value => zio.aws.s3.model.primitives.AccountId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.PutBucketReplicationRequest
  ): zio.aws.s3.model.PutBucketReplicationRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-s3_3-7.21.15.13-sources.jar: zio/aws/s3/model/PutBucketReplicationRequest.scala <==
package zio.aws.s3.model
import zio.aws.s3.model.primitives.{
  AccountId,
  ObjectLockToken,
  ContentMD5,
  BucketName
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class PutBucketReplicationRequest(
    bucket: BucketName,
    contentMD5: Optional[ContentMD5] = Optional.Absent,
    checksumAlgorithm: Optional[zio.aws.s3.model.ChecksumAlgorithm] =
      Optional.Absent,
    replicationConfiguration: zio.aws.s3.model.ReplicationConfiguration,
    token: Optional[ObjectLockToken] = Optional.Absent,
    expectedBucketOwner: Optional[AccountId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.PutBucketReplicationRequest = {
    import PutBucketReplicationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.PutBucketReplicationRequest
      .builder()
      .bucket(BucketName.unwrap(bucket): java.lang.String)
      .optionallyWith(
        contentMD5.map(value => ContentMD5.unwrap(value): java.lang.String)
      )(_.contentMD5)
      .optionallyWith(checksumAlgorithm.map(value => value.unwrap))(
        _.checksumAlgorithm
      )
      .replicationConfiguration(replicationConfiguration.buildAwsValue())
      .optionallyWith(
        token.map(value => ObjectLockToken.unwrap(value): java.lang.String)
      )(_.token)
      .optionallyWith(
        expectedBucketOwner.map(value =>
          AccountId.unwrap(value): java.lang.String
        )
      )(_.expectedBucketOwner)
      .build()
  }
  def asReadOnly: zio.aws.s3.model.PutBucketReplicationRequest.ReadOnly =
    zio.aws.s3.model.PutBucketReplicationRequest.wrap(buildAwsValue())
}
object PutBucketReplicationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.PutBucketReplicationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.PutBucketReplicationRequest =
      zio.aws.s3.model.PutBucketReplicationRequest(
        bucket,
        contentMD5.map(value => value),
        checksumAlgorithm.map(value => value),
        replicationConfiguration.asEditable,
        token.map(value => value),
        expectedBucketOwner.map(value => value)
      )
    def bucket: BucketName
    def contentMD5: Optional[ContentMD5]
    def checksumAlgorithm: Optional[zio.aws.s3.model.ChecksumAlgorithm]
    def replicationConfiguration
        : zio.aws.s3.model.ReplicationConfiguration.ReadOnly
    def token: Optional[ObjectLockToken]
    def expectedBucketOwner: Optional[AccountId]
    def getBucket: ZIO[Any, Nothing, BucketName] = ZIO.succeed(bucket)
    def getContentMD5: ZIO[Any, AwsError, ContentMD5] =
      AwsError.unwrapOptionField("contentMD5", contentMD5)
    def getChecksumAlgorithm
        : ZIO[Any, AwsError, zio.aws.s3.model.ChecksumAlgorithm] =
      AwsError.unwrapOptionField("checksumAlgorithm", checksumAlgorithm)
    def getReplicationConfiguration: ZIO[
      Any,
      Nothing,
      zio.aws.s3.model.ReplicationConfiguration.ReadOnly
    ] = ZIO.succeed(replicationConfiguration)
    def getToken: ZIO[Any, AwsError, ObjectLockToken] =
      AwsError.unwrapOptionField("token", token)
    def getExpectedBucketOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("expectedBucketOwner", expectedBucketOwner)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.PutBucketReplicationRequest
  ) extends zio.aws.s3.model.PutBucketReplicationRequest.ReadOnly {
    override val bucket: BucketName =
      zio.aws.s3.model.primitives.BucketName(impl.bucket())
    override val contentMD5: Optional[ContentMD5] = zio.aws.core.internal
      .optionalFromNullable(impl.contentMD5())
      .map(value => zio.aws.s3.model.primitives.ContentMD5(value))
    override val checksumAlgorithm
        : Optional[zio.aws.s3.model.ChecksumAlgorithm] = zio.aws.core.internal
      .optionalFromNullable(impl.checksumAlgorithm())
      .map(value => zio.aws.s3.model.ChecksumAlgorithm.wrap(value))
    override val replicationConfiguration
        : zio.aws.s3.model.ReplicationConfiguration.ReadOnly =
      zio.aws.s3.model.ReplicationConfiguration
        .wrap(impl.replicationConfiguration())
    override val token: Optional[ObjectLockToken] = zio.aws.core.internal
      .optionalFromNullable(impl.token())
      .map(value => zio.aws.s3.model.primitives.ObjectLockToken(value))
    override val expectedBucketOwner: Optional[AccountId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.expectedBucketOwner())
        .map(value => zio.aws.s3.model.primitives.AccountId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.PutBucketReplicationRequest
  ): zio.aws.s3.model.PutBucketReplicationRequest.ReadOnly = new Wrapper(impl)
}
